@@ -10,6 +10,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
+import struct
 from unittest.mock import Mock, call
 
 import pytest
@@ -128,7 +129,9 @@ class TestGeneric:
             (Port.S1, True, False, Type.COLOR_RED, Mode.RAW, 114, 46, 46, 46),
             (Port.S1, True, False, Type.COLOR_RED, Mode.RAW, 114, 46, 46, 46),
         ]
-        assert s.get_color() == 4
+        color = s.get_color()
+        assert color == 4
+        assert color == s.DetectedColor.YELLOW
         assert s.get_reflected_light(Type.COLOR_RED) == 46
         assert s.get_light_color() == Type.COLOR_RED
         assert mbrick.mock_calls == [
@@ -335,7 +338,7 @@ class TestGenericDigital:
         assert s.get_measurement_units() == "10E-2m"
         assert s.get_all_measurements() == (1, 2, 3, 4, 5, 6, 7, 8)
         assert s.get_measurement_no(3) == 4
-        s.command(s.Commands.OFF)
+        s.command(s.Command.OFF)
         assert s.get_interval() == 43
         s.set_interval(44)
         assert mdigital.mock_calls == [
@@ -354,12 +357,18 @@ class TestGenericDigital:
             is nxt.sensor.generic.Temperature.get_deg_c
         )
         s = mbrick.get_sensor(Port.S1, nxt.sensor.generic.Temperature)
-        mdigital.read_value.return_value = (1600 * 16,)
+        mdigital.read_value.side_effect = [
+            (1600 * 16,),
+            (1600 * 16,),
+            struct.unpack(">h", b"\xff\x80"),
+        ]
         assert s.get_deg_c() == 100
         assert s.get_deg_f() == 212
+        assert s.get_deg_c() == -0.5
         assert mdigital.mock_calls == [
             call.read_value("raw_value"),
             call.read_value("raw_value"),
+            call.read_value("raw_value"),
         ]
 
 
